
# q-expansion of newform 10000.2.a.bi, downloaded from the LMFDB on 01 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 10000
weight = 2
poly_data = [1, 0, -31, 0, 36, 0, -11, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[-3, 0, 1, 0, 0, 0, 0, 0], 1], [[1, 0, -5, 0, 1, 0, 0, 0], 1], [[-7, 0, 16, 0, -8, 0, 1, 0], 4], [[0, -7, 0, 16, 0, -8, 0, 1], 4], [[0, 27, 0, -40, 0, 12, 0, -1], 4], [[0, -43, 0, 44, 0, -12, 0, 1], 4]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -1, 0], [1, 0, 1, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, -2, 0, -1], [0, 1, 0, 0, 0, 3, -2, 1], [2, 0, 0, 2, -1, 0, 0, 0], [0, -1, 0, 0, 0, -1, 3, -2], [-4, 0, -2, 0, 1, 0, 0, 0], [2, 0, -3, 1, 4, 0, 0, 0], [0, -1, 0, 0, 0, 1, 3, 2], [-5, 0, -1, 1, 0, 0, 0, 0], [0, -1, 0, 0, 0, 3, -3, 3], [0, 0, 0, 0, 0, -1, 5, 1], [0, 1, 0, 0, 0, -2, 4, -4], [1, 0, 0, -1, -3, 0, 0, 0], [-5, 0, 1, 0, -2, 0, 0, 0], [0, -1, 0, 0, 0, 5, -2, 5], [-2, 0, -2, -3, 1, 0, 0, 0], [0, -3, 0, 0, 0, -3, 1, 6], [-2, 0, -4, 2, -3, 0, 0, 0], [0, 1, 0, 0, 0, -2, 0, -6], [-11, 0, 3, -3, -6, 0, 0, 0], [0, 4, 0, 0, 0, 1, -3, -7], [-10, 0, 2, -1, -2, 0, 0, 0], [0, -4, 0, 0, 0, -4, 1, 6], [0, 6, 0, 0, 0, 1, -2, -5], [-3, 0, -5, -1, 6, 0, 0, 0], [0, -4, 0, 0, 0, 3, -2, 4], [0, 7, 0, 0, 0, -4, 1, -7], [6, 0, 4, -1, 1, 0, 0, 0], [0, -3, 0, 0, 0, 1, 5, -2], [-1, 0, 1, 2, -10, 0, 0, 0], [-10, 0, 0, -3, 0, 0, 0, 0], [0, 0, 5, -4, -1, 0, 0, 0], [0, -2, 0, 0, 0, 3, 0, 3], [0, -3, 0, 0, 0, -1, -3, 2], [0, 6, 0, 0, 0, 0, 1, 2], [0, -5, 0, 0, 0, 1, -5, 2], [2, 0, 1, -3, 0, 0, 0, 0], [-4, 0, 3, 0, -2, 0, 0, 0], [-1, 0, -1, 3, 4, 0, 0, 0], [0, 0, 0, 0, 0, -6, 0, -6], [0, -9, 0, 0, 0, -1, -2, 1], [-4, 0, 5, -1, -1, 0, 0, 0], [1, 0, 1, -6, 8, 0, 0, 0], [0, 7, 0, 0, 0, -6, 5, -7], [0, -5, 0, 0, 0, 4, 1, 13], [4, 0, 1, 6, 6, 0, 0, 0], [0, 5, 0, 0, 0, 1, 4, -1], [3, 0, 5, -4, 2, 0, 0, 0], [-9, 0, 5, -6, -10, 0, 0, 0], [0, 0, 0, 5, 0, 0, 0, 0], [0, 3, 0, 0, 0, -3, -1, 3], [0, 2, 0, 0, 0, 6, -10, -5], [-4, 0, 3, -4, -4, 0, 0, 0], [-10, 0, -5, 4, -4, 0, 0, 0], [0, -5, 0, 0, 0, -1, -1, 2], [-4, 0, 2, -2, 11, 0, 0, 0], [0, -2, 0, 0, 0, -5, 1, 1], [0, -6, 0, 0, 0, -2, -2, 2], [0, -6, 0, 0, 0, -10, 0, 4], [-11, 0, 0, -2, -11, 0, 0, 0], [0, 7, 0, 0, 0, -4, -3, -9], [0, -3, 0, 0, 0, 0, -4, 6], [-18, 0, -1, -4, 2, 0, 0, 0], [0, 12, 0, 0, 0, 2, 0, -7], [0, -2, 0, 0, 0, 6, -3, -8], [-2, 0, 0, 4, -8, 0, 0, 0], [0, 0, 0, 0, 0, -3, -1, 9], [-7, 0, 4, 0, -3, 0, 0, 0], [0, -2, 0, 0, 0, -1, -1, 9], [0, 2, 0, 0, 0, -7, 16, 0], [-6, 0, 1, 3, -4, 0, 0, 0], [0, 5, 0, 0, 0, 16, -8, 4], [1, 0, 1, 6, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, 9, -12], [-6, 0, 2, 1, 6, 0, 0, 0], [1, 0, -3, 2, -8, 0, 0, 0], [6, 0, 9, -3, 10, 0, 0, 0], [8, 0, -3, 10, 8, 0, 0, 0], [-2, 0, 5, 3, 0, 0, 0, 0], [0, -12, 0, 0, 0, -6, -1, 2], [-1, 0, -6, 4, 13, 0, 0, 0], [0, 2, 0, 0, 0, 5, 10, -5], [-2, 0, -3, 6, -13, 0, 0, 0], [0, -8, 0, 0, 0, 8, -12, 0], [-9, 0, -1, -4, 4, 0, 0, 0], [0, 13, 0, 0, 0, 5, 1, -12], [0, -6, 0, 0, 0, 3, -13, -3], [-10, 0, 6, 4, -5, 0, 0, 0], [0, -5, 0, 0, 0, 1, 11, 2], [3, 0, -3, -4, -6, 0, 0, 0], [-8, 0, -3, -1, -9, 0, 0, 0], [0, -7, 0, 0, 0, 3, 10, 11], [-15, 0, -10, 2, -9, 0, 0, 0], [0, 0, 7, 1, 10, 0, 0, 0], [0, 0, 0, 0, 0, -1, -10, 16], [7, 0, -3, 1, 14, 0, 0, 0], [0, 17, 0, 0, 0, 0, -6, -8], [0, 2, 0, 0, 0, 4, -10, 16], [0, 8, 0, 0, 0, -2, -12, -1], [-16, 0, 3, -1, -20, 0, 0, 0], [2, 0, 5, 5, 10, 0, 0, 0], [0, 15, 0, 0, 0, 2, 1, 5], [0, 3, 0, 0, 0, -15, -1, -10], [0, -3, 0, 0, 0, 6, -5, 8], [4, 0, 2, -1, 18, 0, 0, 0], [-14, 0, -5, -3, 5, 0, 0, 0], [0, 3, 0, 0, 0, 4, -1, 16], [0, 6, 0, 0, 0, 10, -10, -13], [0, 19, 0, 0, 0, 4, -2, -2], [-26, 0, -3, -1, -22, 0, 0, 0], [-18, 0, -1, 3, -2, 0, 0, 0], [3, 0, 8, -12, -5, 0, 0, 0], [0, 4, 0, 0, 0, -8, -2, -18], [0, 13, 0, 0, 0, -7, 0, -19], [0, -4, 0, 0, 0, 5, -1, 13], [29, 0, -9, 7, 30, 0, 0, 0], [23, 0, 0, 1, -1, 0, 0, 0], [0, 7, 0, 0, 0, -10, 5, -9], [0, -6, 0, 0, 0, -20, 14, -7], [0, 3, 0, 0, 0, -6, -10, -10], [7, 0, 0, 1, 19, 0, 0, 0], [-6, 0, -16, -4, 20, 0, 0, 0], [1, 0, 7, -6, 10, 0, 0, 0], [18, 0, -3, 5, 22, 0, 0, 0], [0, -2, 0, 0, 0, 5, -4, -4], [0, 12, 0, 0, 0, 6, 3, -10], [-13, 0, 2, -5, -7, 0, 0, 0], [0, -2, 0, 0, 0, 12, -12, 10], [-24, 0, 2, -5, -2, 0, 0, 0], [0, 0, 0, 0, 0, -23, 18, -11], [-29, 0, 6, 3, -3, 0, 0, 0], [20, 0, -11, 8, 26, 0, 0, 0], [0, 10, 0, 0, 0, 15, -4, -6], [0, 15, 0, 0, 0, 16, -3, 1], [0, -7, 0, 0, 0, -6, 6, 0], [-19, 0, -8, 6, -3, 0, 0, 0], [21, 0, 1, 4, 8, 0, 0, 0], [20, 0, -2, 1, 23, 0, 0, 0], [0, -11, 0, 0, 0, -14, 7, -11], [0, -2, 0, 0, 0, -19, 16, 4], [16, 0, -6, 3, 13, 0, 0, 0], [7, 0, 2, 3, 29, 0, 0, 0], [0, 5, 0, 0, 0, -5, 6, -15], [0, 7, 0, 0, 0, 11, -5, 17], [-3, 0, 1, -8, -24, 0, 0, 0], [0, -12, 0, 0, 0, -13, -2, -4], [0, 9, 0, 0, 0, -8, -1, -9], [12, 0, -5, 14, 6, 0, 0, 0], [0, -3, 0, 0, 0, -7, 14, -3], [0, -1, 0, 0, 0, -4, -3, 5], [0, -6, 0, 0, 0, 17, -10, 7], [-19, 0, 19, -4, -22, 0, 0, 0], [-26, 0, 2, -2, -3, 0, 0, 0], [-20, 0, -2, 1, -11, 0, 0, 0], [0, 0, 0, 0, 0, 17, -6, 20], [-13, 0, -3, 4, -10, 0, 0, 0], [0, -15, 0, 0, 0, 3, 16, 7], [0, 2, 0, 0, 0, -15, -3, -7], [0, -19, 0, 0, 0, 5, 0, 13], [42, 0, -4, 6, 7, 0, 0, 0], [0, 11, 0, 0, 0, 9, 11, -4], [0, 16, 0, 0, 0, -16, 5, -18], [-17, 0, 1, -10, -10, 0, 0, 0], [0, 1, 0, 0, 0, 6, -14, 4], [-3, 0, 9, -10, -8, 0, 0, 0], [0, 0, 0, 0, 0, 12, 8, 25], [-2, 0, -9, -1, -4, 0, 0, 0], [-20, 0, 2, 4, -13, 0, 0, 0], [6, 0, 2, 4, -9, 0, 0, 0], [0, 11, 0, 0, 0, 10, -20, 4], [-21, 0, -5, -4, -20, 0, 0, 0], [2, 0, 0, 15, 20, 0, 0, 0], [36, 0, -8, 6, 36, 0, 0, 0], [-17, 0, 11, -4, 4, 0, 0, 0], [0, 3, 0, 0, 0, -9, 15, -6], [-8, 0, -12, 11, -9, 0, 0, 0], [0, -17, 0, 0, 0, -11, 11, 2], [-1, 0, 7, 5, -32, 0, 0, 0], [0, 1, 0, 0, 0, 9, 17, -5], [0, 17, 0, 0, 0, -1, -8, -7], [0, -9, 0, 0, 0, -10, -6, 14], [-15, 0, 9, -16, 4, 0, 0, 0], [0, 17, 0, 0, 0, 0, -4, -6], [0, -2, 0, 0, 0, 20, -10, 9], [24, 0, -3, -6, 14, 0, 0, 0], [8, 0, -5, 12, -7, 0, 0, 0], [0, 14, 0, 0, 0, -15, -7, -31], [0, -5, 0, 0, 0, 14, -23, 13], [22, 0, -12, 3, 27, 0, 0, 0], [-36, 0, 7, -2, -26, 0, 0, 0], [0, -18, 0, 0, 0, 18, -22, 5], [0, 9, 0, 0, 0, -6, -1, -8], [22, 0, 22, 0, -10, 0, 0, 0], [0, 2, 0, 0, 0, -7, -4, 6], [0, -11, 0, 0, 0, 3, -18, 5], [0, -23, 0, 0, 0, -11, 17, -16], [16, 0, 3, -4, 40, 0, 0, 0], [-2, 0, 1, -15, -8, 0, 0, 0], [0, 11, 0, 0, 0, 24, -7, 17], [10, 0, 5, 0, 27, 0, 0, 0], [-15, 0, -1, -5, -2, 0, 0, 0], [0, -10, 0, 0, 0, 11, -8, -8], [26, 0, -4, 3, 45, 0, 0, 0], [0, -12, 0, 0, 0, 1, -9, -9], [-3, 0, 1, 16, 12, 0, 0, 0], [47, 0, -3, 1, 14, 0, 0, 0], [0, 8, 0, 0, 0, 0, -13, -8], [-22, 0, -2, 1, -18, 0, 0, 0], [0, 15, 0, 0, 0, 4, -14, 4], [0, -15, 0, 0, 0, 4, 1, 12], [6, 0, 10, -3, 9, 0, 0, 0], [12, 0, -5, -5, 14, 0, 0, 0], [0, -26, 0, 0, 0, -2, -2, 5], [-13, 0, -22, 6, -7, 0, 0, 0], [0, -23, 0, 0, 0, -3, 4, -7], [0, -1, 0, 0, 0, 5, -29, -2], [-12, 0, -1, 1, -34, 0, 0, 0], [24, 0, 6, 10, -26, 0, 0, 0], [5, 0, 5, 6, -12, 0, 0, 0], [0, -6, 0, 0, 0, -21, 8, -20], [0, -3, 0, 0, 0, 20, 11, 17], [-20, 0, -12, 6, -1, 0, 0, 0], [0, -1, 0, 0, 0, -2, -4, -16], [7, 0, 25, 0, -6, 0, 0, 0], [0, -2, 0, 0, 0, 19, -21, 13], [-8, 0, -7, -7, -1, 0, 0, 0], [0, 0, 0, 0, 0, 6, 17, 14], [1, 0, -15, 9, 4, 0, 0, 0], [54, 0, 1, 2, 14, 0, 0, 0], [-32, 0, 5, -8, -4, 0, 0, 0], [0, -5, 0, 0, 0, 17, -4, 21], [0, 21, 0, 0, 0, -8, -5, -3], [13, 0, -4, 1, 13, 0, 0, 0], [0, -29, 0, 0, 0, -5, 3, 13], [24, 0, 5, 1, 7, 0, 0, 0], [-3, 0, -15, -8, -8, 0, 0, 0], [0, 6, 0, 0, 0, -29, 12, -16], [-2, 0, -5, -14, -18, 0, 0, 0], [0, -3, 0, 0, 0, -1, -17, 23], [26, 0, -11, 5, 15, 0, 0, 0], [0, -8, 0, 0, 0, -1, -17, -5], [13, 0, -16, 6, 21, 0, 0, 0], [0, 5, 0, 0, 0, 0, 30, 4], [-6, 0, -15, 1, -2, 0, 0, 0], [2, 0, -3, 7, -32, 0, 0, 0], [0, -3, 0, 0, 0, -23, 22, -19], [0, 1, 0, 0, 0, 2, 18, 0], [-14, 0, 6, 13, 10, 0, 0, 0], [0, 5, 0, 0, 0, 9, 7, -19], [9, 0, 6, -11, 3, 0, 0, 0], [0, -3, 0, 0, 0, -30, 19, -7], [-10, 0, -1, -9, -24, 0, 0, 0], [28, 0, -18, -1, 7, 0, 0, 0], [0, 23, 0, 0, 0, 0, 5, 1], [0, 11, 0, 0, 0, 0, -15, -11], [0, -8, 0, 0, 0, 19, 10, 11], [0, -1, 0, 0, 0, -4, 29, -1], [0, 20, 0, 0, 0, 2, 3, -20], [-20, 0, 8, -9, -13, 0, 0, 0], [0, 0, 0, 0, 0, -15, -6, 1], [0, -25, 0, 0, 0, 13, -22, 15], [24, 0, 0, -10, 16, 0, 0, 0], [21, 0, -6, 10, 23, 0, 0, 0], [-44, 0, 3, -2, 6, 0, 0, 0], [0, 11, 0, 0, 0, 19, -25, 14], [0, 3, 0, 0, 0, 24, -4, 14], [-1, 0, 3, 4, -24, 0, 0, 0], [0, 0, 0, 0, 0, -13, 25, -7], [0, -18, 0, 0, 0, 8, -13, 0], [1, 0, 19, -6, -6, 0, 0, 0], [0, -28, 0, 0, 0, -4, 4, 17], [0, -15, 0, 0, 0, -8, 0, 16], [0, 1, 0, 0, 0, -5, 1, 4], [25, 0, 5, -3, 28, 0, 0, 0], [38, 0, -12, 17, 4, 0, 0, 0], [17, 0, 2, 5, -33, 0, 0, 0], [0, -2, 0, 0, 0, 4, -6, -7], [-2, 0, 10, 13, -5, 0, 0, 0], [0, -26, 0, 0, 0, 25, -29, 15], [-1, 0, -5, -14, 8, 0, 0, 0], [0, 20, 0, 0, 0, 9, -7, -29], [-30, 0, 5, 4, 14, 0, 0, 0], [0, 5, 0, 0, 0, -1, 1, -20], [0, 3, 0, 0, 0, 21, -5, 16], [-38, 0, -9, -7, -2, 0, 0, 0], [9, 0, -4, -11, 25, 0, 0, 0], [-6, 0, 6, 14, -10, 0, 0, 0], [0, 8, 0, 0, 0, 18, 22, 0], [0, -17, 0, 0, 0, 13, -13, 8], [10, 0, 11, -17, 10, 0, 0, 0], [0, -24, 0, 0, 0, 1, 1, 9], [22, 0, -18, 3, 14, 0, 0, 0], [4, 0, 5, -4, -37, 0, 0, 0], [0, -8, 0, 0, 0, -13, 14, -22], [-6, 0, -16, 12, 9, 0, 0, 0], [0, -9, 0, 0, 0, 11, -29, 4], [0, 21, 0, 0, 0, -8, 19, -10], [0, -3, 0, 0, 0, -22, 10, -8], [0, 0, -10, -5, 34, 0, 0, 0], [0, -11, 0, 0, 0, 10, -8, -2], [37, 0, 10, -7, -5, 0, 0, 0], [0, -11, 0, 0, 0, -24, 8, -10], [0, -6, 0, 0, 0, 19, 0, 22], [-20, 0, 14, -11, -31, 0, 0, 0], [-21, 0, -7, 12, 10, 0, 0, 0], [0, 24, 0, 0, 0, 6, -11, 2], [0, 17, 0, 0, 0, -12, -17, -13], [24, 0, -13, 0, -8, 0, 0, 0], [8, 0, -5, -2, -22, 0, 0, 0], [0, 9, 0, 0, 0, 1, -6, 17], [0, -8, 0, 0, 0, 24, 8, 47], [-11, 0, 5, 4, -44, 0, 0, 0], [16, 0, 6, 3, 14, 0, 0, 0], [-43, 0, -6, 2, -21, 0, 0, 0], [0, -1, 0, 0, 0, 7, 15, 14], [4, 0, -11, -1, 6, 0, 0, 0], [-22, 0, -14, -1, 15, 0, 0, 0], [0, 8, 0, 0, 0, -16, -4, 3], [19, 0, -1, 6, -20, 0, 0, 0], [0, 16, 0, 0, 0, 23, 4, -11], [0, -7, 0, 0, 0, 26, -12, 36], [43, 0, -5, 7, 12, 0, 0, 0], [6, 0, -4, 4, 21, 0, 0, 0], [0, -1, 0, 0, 0, -22, 38, -14], [0, -27, 0, 0, 0, 7, 11, 15], [0, 1, 0, 0, 0, 6, -5, 21], [16, 0, 2, -10, 11, 0, 0, 0], [0, -4, 0, 0, 0, 10, -28, 5], [11, 0, -3, 2, 14, 0, 0, 0], [0, -36, 0, 0, 0, -14, 22, -12], [-72, 0, 5, -11, -5, 0, 0, 0], [0, -6, 0, 0, 0, -8, -19, -10], [24, 0, 13, -11, -10, 0, 0, 0], [0, 20, 0, 0, 0, 5, -6, -32], [16, 0, 31, -7, -6, 0, 0, 0], [0, 7, 0, 0, 0, -14, 25, -1], [0, 22, 0, 0, 0, -3, -8, 5], [0, -15, 0, 0, 0, 8, 2, 30], [-19, 0, 19, 5, -22, 0, 0, 0], [17, 0, 6, -9, -25, 0, 0, 0], [0, 30, 0, 0, 0, 17, 15, -31], [-21, 0, -9, -5, 44, 0, 0, 0], [27, 0, -1, 1, 16, 0, 0, 0], [0, 1, 0, 0, 0, -24, 2, -28], [0, 0, -4, 8, 12, 0, 0, 0], [0, 25, 0, 0, 0, -3, 25, -25], [30, 0, 14, 10, -7, 0, 0, 0], [0, -15, 0, 0, 0, -19, 13, -28], [20, 0, 3, -9, -14, 0, 0, 0], [0, 11, 0, 0, 0, -11, -20, 5], [5, 0, -8, -1, 13, 0, 0, 0], [0, -27, 0, 0, 0, 4, 7, 38], [-12, 0, -15, 1, 19, 0, 0, 0], [1, 0, 6, 16, -1, 0, 0, 0], [0, -3, 0, 0, 0, 22, -8, 12], [0, 0, 0, 0, 0, 4, 0, -7], [0, 8, 0, 0, 0, 12, -12, 3], [-25, 0, -3, -13, 10, 0, 0, 0], [0, 30, 0, 0, 0, -14, -11, -32], [9, 0, -9, -9, 2, 0, 0, 0], [0, -6, 0, 0, 0, -2, 17, 20], [0, -36, 0, 0, 0, 9, -14, 16], [0, 12, 0, 0, 0, -16, 16, 9], [0, 0, 0, 0, 0, -24, 5, -26], [-4, 0, 10, -15, 27, 0, 0, 0], [-2, 0, -13, 14, 2, 0, 0, 0], [7, 0, 36, -2, -21, 0, 0, 0], [0, 14, 0, 0, 0, 11, -2, 1], [-2, 0, 5, -1, 7, 0, 0, 0], [-24, 0, -17, -3, 9, 0, 0, 0], [0, 34, 0, 0, 0, -2, -6, 2], [30, 0, 9, -2, -16, 0, 0, 0], [-29, 0, -5, -5, -44, 0, 0, 0], [0, -24, 0, 0, 0, -7, -14, 29], [1, 0, -11, -8, 36, 0, 0, 0], [0, 13, 0, 0, 0, 9, 6, -21], [20, 0, 3, 10, -38, 0, 0, 0], [0, 2, 0, 0, 0, 7, -25, -37], [0, -9, 0, 0, 0, 11, 10, 31], [0, 11, 0, 0, 0, 19, 3, -7], [13, 0, -15, 19, 24, 0, 0, 0], [0, 30, 0, 0, 0, -9, 28, -12], [38, 0, -26, 16, 37, 0, 0, 0], [0, -7, 0, 0, 0, 11, -3, -14], [0, 26, 0, 0, 0, -5, 13, -35], [0, -11, 0, 0, 0, 0, -25, 13], [25, 0, -4, 2, 5, 0, 0, 0], [0, 7, 0, 0, 0, -13, 19, 13], [0, 0, 5, -3, 31, 0, 0, 0], [0, -7, 0, 0, 0, -4, 5, 0], [-3, 0, 15, -10, 26, 0, 0, 0], [0, -3, 0, 0, 0, 15, -11, 30], [-30, 0, 13, -14, -14, 0, 0, 0], [4, 0, -21, -4, 32, 0, 0, 0], [66, 0, -5, 5, 6, 0, 0, 0], [-21, 0, 6, -5, -27, 0, 0, 0], [-18, 0, 2, -13, 26, 0, 0, 0], [0, 19, 0, 0, 0, -17, 16, 1], [0, 20, 0, 0, 0, 23, -11, 5], [0, 6, 0, 0, 0, 14, -10, 31], [-3, 0, -6, -13, 35, 0, 0, 0], [-1, 0, -11, 0, -14, 0, 0, 0], [0, 20, 0, 0, 0, -10, 3, -6], [-10, 0, 8, -4, -56, 0, 0, 0], [0, 21, 0, 0, 0, -5, 22, -21], [42, 0, -5, 5, 44, 0, 0, 0], [0, -7, 0, 0, 0, 22, -14, 20], [0, -26, 0, 0, 0, 0, -18, 27], [0, 15, 0, 0, 0, 12, -9, -8], [32, 0, -24, 2, 48, 0, 0, 0], [0, 13, 0, 0, 0, -13, -19, -35], [7, 0, 27, -17, -8, 0, 0, 0], [-22, 0, -10, -6, -21, 0, 0, 0], [0, -16, 0, 0, 0, -35, 34, -4], [0, -9, 0, 0, 0, -8, 16, -26], [0, -29, 0, 0, 0, 8, -6, 40], [-27, 0, -16, -8, 17, 0, 0, 0], [0, 20, 0, 0, 0, -12, -7, -24], [0, 34, 0, 0, 0, 7, 8, -14], [7, 0, -38, 8, 25, 0, 0, 0], [0, 3, 0, 0, 0, 17, 0, -21], [0, -13, 0, 0, 0, -14, 21, 16], [0, -6, 0, 0, 0, -10, 6, 27], [-56, 0, -29, 17, -20, 0, 0, 0], [-10, 0, 29, -16, -22, 0, 0, 0], [-48, 0, 12, -4, -36, 0, 0, 0]]
